@@ -285,18 +285,34 @@ gedit_handle_automation_cmdline (GnomeProgram *program)
 
 	if (stdin_data != NULL && strlen (stdin_data) > 0)
 	{
+		GError *conv_error = NULL;
+		const GeditEncoding *encoding;
 		gchar *converted_text;
 
-		if (g_utf8_validate (stdin_data, -1, NULL))
+		if (gedit_encoding_get_current () != gedit_encoding_get_utf8 ())
 		{
-			converted_text = stdin_data;
-			stdin_data = NULL;
+			if (g_utf8_validate (stdin_data, -1, NULL))
+			{
+				converted_text = stdin_data;
+				stdin_data = NULL;
+
+				encoding = gedit_encoding_get_utf8 ();
+			}
+			else
+			{
+				converted_text = NULL;
+			}
 		}
 		else
+		{	
+			encoding = gedit_encoding_get_current ();
+				
 			converted_text = gedit_convert_to_utf8 (stdin_data,
-							-1,
-							NULL);
-
+								-1,
+								&encoding,
+								&conv_error);
+		}	
+		
 		if (converted_text != NULL)
 		{
 			window = GNOME_Gedit_Application_getActiveWindow (server, &env);
@@ -335,8 +351,9 @@ main (int argc, char **argv)
 	gboolean restored = FALSE;
 	CORBA_Object factory;
 
+	setlocale (LC_ALL, "");
+
 	bindtextdomain (GETTEXT_PACKAGE, GEDIT_LOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
 	/* Initialize gnome program */
@@ -348,6 +365,8 @@ main (int argc, char **argv)
 			    GNOME_PARAM_APP_DATADIR, DATADIR,
 			    NULL);
 
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
 	/* check whether we are running already */
         factory = bonobo_activation_activate_from_id
                 ("OAFIID:GNOME_Gedit_Factory",
@@ -376,6 +395,8 @@ main (int argc, char **argv)
 	/* Init plugins engine */
 	gedit_plugins_engine_init ();
 
+	gnome_authentication_manager_init ();
+
 	/* Initialize session management */
 	gedit_session_init (argv[0]);
 
